@@ -309,11 +309,25 @@ static Obj FuncDEFAULT_SIGCHLD_HANDLER(Obj self)
 // posix_spawn_file_actions_addchdir_np. To keep things simple, we detect this
 // case and use some preprocessor tricks to make things work in either case.
 //
-#if !defined(HAVE_POSIX_SPAWN_FILE_ACTIONS_ADDCHDIR) &&                      \
+// macOS 26 has posix_spawn_file_actions_addchdir, but Xcode generates
+// code which uses it even in older versions of macOS. Therefore if both
+// functions are defined, we will always use the older _np version.
+// See issue <https://github.com/gap-system/gap/issues/6118> for details.
+#if defined(HAVE_POSIX_SPAWN_FILE_ACTIONS_ADDCHDIR) ||                       \
     defined(HAVE_POSIX_SPAWN_FILE_ACTIONS_ADDCHDIR_NP)
+
+#if !defined(HAVE_POSIX_SPAWN_FILE_ACTIONS_ADDCHDIR)
 #define HAVE_POSIX_SPAWN_FILE_ACTIONS_ADDCHDIR
-#define posix_spawn_file_actions_addchdir(f, d)                              \
+#endif
+
+#if HAVE_POSIX_SPAWN_FILE_ACTIONS_ADDCHDIR_NP
+#define posix_spawn_file_actions_addchdir_func(f, d)                         \
     posix_spawn_file_actions_addchdir_np(f, d)
+#else
+#define posix_spawn_file_actions_addchdir_func(f, d)                         \
+    posix_spawn_file_actions_addchdir(f, d)
+#endif
+
 #endif
 
 
@@ -368,9 +382,12 @@ static int posix_spawn_with_dir(pid_t *                      pid,
     // the next POSIX revision in mid-2020. When this will appear in public
     // is anyones guess. On the upside, also OpenBSD, FreeBSD, and Solaris
     // implement the _np versions of the API.
+    //
+    // UPDATE: For now we still prefer the _np version if available, to
+    // avoid issues in macOS 26 (see <https://github.com/gap-system/gap/issues/6118>.
 
 #ifdef HAVE_POSIX_SPAWN_FILE_ACTIONS_ADDCHDIR
-    if (posix_spawn_file_actions_addchdir(file_actions, dir)) {
+    if (posix_spawn_file_actions_addchdir_func(file_actions, dir)) {
         PErr("posix_spawn_with_dir: addchdir failed");
         return 1;
     }
